import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { useContext, } from "react";
import { useMMenuBarOcup } from "./MainMenuBar";
import { useTheme } from "./Theme/Providers";
import { animate, motion, useMotionValue } from "framer-motion";
import { DdMenu, DdMenuItem } from "./DropdownMenu";
import { Menu2Item } from "./Menu";
import { IconChevronsLeft } from "./Icons";
/**应该放在<TwoHalfFrame>的头上引入。 TwoHalfFrame下面右半边页面必须<TwoHalfRightPanel>包裹的。
 * 右半边详细操作页面被放大为整个视口的页面，放大
 * 跨越多层次的APP路由器页面。
 * */
export const PanelEnlargeCtx = React.createContext({
    enlarge: undefined,
    setEnlarge: value => null,
    activecas: undefined,
    setActivecas: value => null,
});
const containerStyle = {
    position: "relative",
    width: "100%",
    height: "100%",
    overflowX: "hidden",
    display: "flex",
};
const pageStyle = {
    display: "inline-block",
    flex: "none",
};
const transition = {
    type: "spring",
    bounce: 0,
};
/**公用框架组件  Left左半列表摘要 + 右半边Console详细操作的页面。
 * TwoHalfFrame应该放在路由器每个路由顶部，外部加个PanelEnlargeCtx.Provider配套控制本实例TwoHalfFrame。
 * 本组件是框架，要配合 <TwoHalfRightPanel/>组件 以及<PanelEnlargeCtx.Provider 这两个东西来协同完成框架页面构建。
 * 需要在页面路由器头上加<PanelEnlargeCtx.Provider  value={{ enlarge, setEnlarge，activecas，setActivecas }}>
 * */
export const TwoHalfFrame = ({ children, rightPanel, ...other }) => {
    const theme = useTheme();
    const { enlarge, setEnlarge, activecas, setActivecas } = useContext(PanelEnlargeCtx);
    const containerRef = React.useRef(null);
    const x = useMotionValue(0);
    const calculateNewX = React.useCallback(() => -activecas * (containerRef.current?.clientWidth || 0), [activecas]);
    const handleEndDrag = (e, dragProps) => {
        const clientWidth = containerRef.current?.clientWidth || 0;
        const { offset, velocity } = dragProps;
        const xDrag = Math.abs(velocity.x) > Math.abs(velocity.y);
        if (!xDrag) {
            return animate(x, calculateNewX(), transition);
        }
        if (offset.x > clientWidth / 4) {
            handlePrev();
        }
        else if (offset.x < -clientWidth / 4) {
            handleNext();
        }
        else {
            animate(x, calculateNewX(), transition);
        }
    };
    const childrens = [children, rightPanel];
    const handleNext = () => {
        const toIndex = (activecas + 1) >= childrens.length ? 0 : (activecas + 1);
        setActivecas(toIndex);
    };
    //原地踏步吗：true。
    const handlePrev = () => {
        const toIndex = (activecas - 1 < 0) ? (childrens.length - 1) : (activecas - 1);
        setActivecas(toIndex);
    };
    const { barHeight, bottomCss, carousel, isBigSrc, mobileList } = useMMenuBarOcup(!rightPanel);
    //父辈路由使用TwoHalfFrame，儿子路由用TwoHalfRightPanel,不同儿子路由切换不会引发本组件remount,所以仅仅上级路由切换的才走这里逻辑
    React.useEffect(() => {
        setActivecas(carousel ? 1 : 0); //初始化轮播组件切到：主工做的右边明细页面。
    }, [carousel, setActivecas]);
    React.useEffect(() => {
        if (carousel) {
            const controls = animate(x, calculateNewX(), transition);
            return controls.stop;
        }
    }, [calculateNewX, activecas, x, carousel]);
    //非手机轮播台模式的左右两半边页面宽度比例： 左边没有=0，1：左边右边1比2， 2： 1比1， 3： 2比1， 4：右边没有。
    const leftpwp = enlarge === 0 ? 0 : (enlarge === 1 ? 33.4 : (enlarge === 4 ? 100 : (enlarge === 3 ? 66.6 : 50)));
    // const { carousel, barHeight,bottomCss } = useMMenuBarOcup(false,false);
    return (_jsxs(_Fragment, { children: [_jsxs("div", { className: "thFrame", ref: containerRef, style: containerStyle, children: [_jsx(motion.div, { style: {
                            ...pageStyle,
                            x,
                            left: `0%`,
                            right: `0%`,
                            width: (carousel || mobileList) ? "100%" : `${leftpwp}%`,
                            // minHeight:  `calc(100vh - ${barHeight})`,
                        }, css: {
                            height: `calc(100vh - ${barHeight})`,
                            overflowY: 'auto',
                        }, drag: carousel ? "x" : false, dragElastic: 0.3, onDragEnd: handleEndDrag, dragDirectionLock: true, children: childrens[0] }, 1), _jsx(motion.div, { style: {
                            ...pageStyle,
                            x,
                            left: `100%`,
                            right: `100%`,
                            width: carousel ? "100%" : mobileList ? '0%' : `${100 - leftpwp}%`,
                            // minHeight: carousel? `calc(100vh - ${barHeight})` : 'unset',
                        }, css: {
                            height: carousel ? `calc(100vh - ${barHeight})` : '100%',
                        }, drag: carousel ? "x" : false, dragElastic: 0.3, onDragEnd: handleEndDrag, dragDirectionLock: true, children: childrens[1] }, 2)] }), _jsx("div", { css: {
                    display: 'inline-flex',
                    position: "fixed",
                    bottom: 0,
                    right: 0,
                    minHeight: `${barHeight}`,
                }, children: _jsxs(DdMenu, { label: "\u653E\u5927", tight: true, icon: _jsx(Menu2Item, { variant: "ghost", component: "div", children: _jsx(IconChevronsLeft, { size: isBigSrc ? "lg" : "md" }) }), children: [_jsx(DdMenuItem, { label: "\u5DE6\u6EE1\u5C4F", onClick: (e) => { setEnlarge(4); } }), _jsx(DdMenuItem, { label: "1\u6BD42", onClick: (e) => { setEnlarge(1); } }), _jsx(DdMenuItem, { label: "1\u6BD41", onClick: (e) => { setEnlarge(2); } }), _jsx(DdMenuItem, { label: "2\u6BD41", onClick: (e) => { setEnlarge(3); } }), _jsx(DdMenuItem, { label: "\u53F3\u6EE1\u5C4F", onClick: (e) => { setEnlarge(0); } })] }) })] }));
};
//# sourceMappingURL=TwoHalfFrame.js.map